============
ANSEL Codecs
============


.. image:: https://img.shields.io/pypi/v/ansel.svg
        :target: https://pypi.python.org/pypi/ansel

.. image:: https://img.shields.io/travis/haney/python-ansel.svg
        :target: https://travis-ci.org/haney/python-ansel

.. image:: https://readthedocs.org/projects/python-ansel/badge/?version=latest
        :target: https://python-ansel.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Codecs for reading/writing documents in the ANSEL character set.


* Free software: MIT license
* Documentation: https://python-ansel.readthedocs.io.


Features
--------

* Adds support for new encodings ANSEL_ (ANSI/NISO Z39.47) and GEDCOM_.
* Re-orders combining characters for consistency with the ANSEL specification.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _ANSEL: https://en.wikipedia.org/wiki/ANSEL
.. _GEDCOM: https://en.wikipedia.org/wiki/GEDCOM
